#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cmd_ts_1 = require("cmd-ts");
const fs_1 = require("cmd-ts/batteries/fs");
const package_json_1 = require("../package.json");
const lib_1 = require("./lib");
const cmd = (0, cmd_ts_1.command)({
    name: "img-cat",
    description: "display images in the terminal",
    version: package_json_1.version,
    args: {
        firstFile: (0, cmd_ts_1.positional)({
            type: fs_1.File,
        }),
        otherFiles: (0, cmd_ts_1.restPositionals)({
            type: fs_1.File,
        }),
        noPadding: (0, cmd_ts_1.flag)({
            long: "no-padding",
            short: "n",
            description: "display image without any padding",
        }),
        trueColor: (0, cmd_ts_1.flag)({
            long: "true-color",
            short: "t",
            description: "display image using true color (24-bit)",
        }),
    },
    async handler({ firstFile, otherFiles, noPadding, trueColor }) {
        const files = [firstFile, ...otherFiles];
        for (const filename of files) {
            const str = await (0, lib_1.fromFile)(filename, {
                padding: !noPadding,
                trueColor: trueColor,
            });
            console.log(str);
        }
    },
});
(0, cmd_ts_1.run)((0, cmd_ts_1.binary)(cmd), process.argv);
